5.12 IOT
=========

It describes an IoT device.

Type: :py:class:`~otupy.profiles.ctxd.data.iot.IOT` (:py:class:`~otupy.types.base.record.Record`)

.. list-table::
   :widths: 3 4 4 3 40
   :header-rows: 1

   * - ID
     - Name
     - Type
     - #
     - Description
   * - 1
     - description
     - ``str``
     - 1
     - Identifier of the IoT function.
   * - 2
     - name
     - ``str``
     - 1
     - Name of the IoT service provider.
   * - 3
     - type
     - ``str``
     - 1
     - Type of the IoT device.

Sample IOT object represented in JSON Format:

.. code:: json

   {
     "description": "IoT",
     "name": "Azure IoT",
     "type": "sensor"
   }

